/*-
# X-BASED SKEWB
#
#  Skewb3d.h
#
###
#
#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "playable",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Skewb3d */

#ifndef _XtSkewb3d_h
#define _XtSkewb3d_h

/***********************************************************************
 *
 * Skewb3d Widget
 *
 ***********************************************************************/

#include "Skewb.h"

typedef struct _Skewb3DRec *Skewb3DWidget;
#ifndef WINVER
typedef struct _Skewb3DClassRec *Skewb3DWidgetClass;
extern WidgetClass skewb3dWidgetClass;
#endif

#endif /* _XtSkewb3d_h */
/* DON'T ADD STUFF AFTER THIS #endif */
